@@ -27,7 +27,7 @@ extern "C" {
 
 /**
  * \defgroup CWMakeFakeData_h Header CWMakeFakeData.h
- * \ingroup pkg_pulsarCommon
+ * \ingroup lalpulsar_inject
  * \author Reinhard Prix, Karl Wette
  *
  * \brief Module for generating 'fake' data containing CW signals and/or Gaussian noise.
@@ -101,7 +101,7 @@ REAL4TimeSeries *
 XLALGenerateCWSignalTS ( const PulsarParams *pulsarParams, const LALDetector *site, LIGOTimeGPS startTime, REAL8 duration, REAL8 fSamp, REAL8 fHet, const EphemerisData *edat );
 
 
-int XLALReadPulsarParams ( PulsarParams *pulsarParams, const LALParsedDataFile *cfgdata, const CHAR *secName );
+int XLALReadPulsarParams ( PulsarParams *pulsarParams, LALParsedDataFile *cfgdata, const CHAR *secName );
 PulsarParamsVector *XLALPulsarParamsFromFile ( const char *fname );
 PulsarParamsVector *XLALPulsarParamsFromUserInput ( const LALStringVector *UserInput );
 
