@@ -253,39 +253,42 @@ int XLALCreateSFTPairIndexList
 /** Construct vector of G_alpha amplitudes for each SFT pair */
 /* This is averaged over unknown cosi and psi */
 /* Allocates memory as well */
-int XLALCalculateAveCurlyGAmpUnshifted
+int XLALCalculateCrossCorrGammas
   (
-   REAL8Vector            **G_alpha, /* Output: vector of sigma_alpha values */
+   REAL8Vector          **Gamma_ave, /* Output: vector of aa+bb values */
+   REAL8Vector         **Gamma_circ, /* Output: vector of ab-ba values */
    SFTPairIndexList  *pairIndexList, /* Input: list of SFT pairs */
    SFTIndexList          *indexList, /* Input: list of SFTs */
    MultiAMCoeffs       *multiCoeffs  /* Input: AM coefficients */
   )
 {
 
-  UINT8 j, numPairs;
-  UINT8 detInd1, detInd2;
-  UINT8 sftInd1, sftInd2;
-  UINT8 sftNum1, sftNum2;
-  REAL8Vector *ret = NULL;
+  UINT8 numPairs = pairIndexList->length;
 
-  numPairs = pairIndexList->length;
+  REAL8Vector *ret1 = NULL;
+  XLAL_CHECK ( ( ret1 = XLALCreateREAL8Vector ( numPairs ) ) != NULL, XLAL_EFUNC, "XLALCreateREAL8Vector ( %"LAL_UINT8_FORMAT" ) failed.", numPairs );
+  REAL8Vector *ret2 = NULL;
+  XLAL_CHECK ( ( ret2 = XLALCreateREAL8Vector ( numPairs ) ) != NULL, XLAL_EFUNC, "XLALCreateREAL8Vector ( %"LAL_UINT8_FORMAT" ) failed.", numPairs );
 
-  XLAL_CHECK ( ( ret = XLALCreateREAL8Vector ( numPairs ) ) != NULL, XLAL_EFUNC, "XLALCreateREAL8Vector ( %"LAL_UINT8_FORMAT" ) failed.", numPairs );
-
-  for (j=0; j < numPairs; j++) {
-    sftNum1 = pairIndexList->data[j].sftNum[0];
-    sftNum2 = pairIndexList->data[j].sftNum[1];
-    detInd1 = indexList->data[sftNum1].detInd;
-    detInd2 = indexList->data[sftNum2].detInd;
-    sftInd1 = indexList->data[sftNum1].sftInd;
-    sftInd2 = indexList->data[sftNum2].sftInd;
-    ret->data[j] = 0.1 * ( multiCoeffs->data[detInd1]->a->data[sftInd1]
+  for (UINT8 j=0; j < numPairs; j++) {
+    UINT8 sftNum1 = pairIndexList->data[j].sftNum[0];
+    UINT8 sftNum2 = pairIndexList->data[j].sftNum[1];
+    UINT8 detInd1 = indexList->data[sftNum1].detInd;
+    UINT8 detInd2 = indexList->data[sftNum2].detInd;
+    UINT8 sftInd1 = indexList->data[sftNum1].sftInd;
+    UINT8 sftInd2 = indexList->data[sftNum2].sftInd;
+    ret1->data[j] = 0.1 * ( multiCoeffs->data[detInd1]->a->data[sftInd1]
 			   * multiCoeffs->data[detInd2]->a->data[sftInd2]
 			   + multiCoeffs->data[detInd1]->b->data[sftInd1]
 			   * multiCoeffs->data[detInd2]->b->data[sftInd2] );
+    ret2->data[j] = 0.1 * ( multiCoeffs->data[detInd1]->a->data[sftInd1]
+			   * multiCoeffs->data[detInd2]->b->data[sftInd2]
+			   - multiCoeffs->data[detInd1]->b->data[sftInd1]
+			   * multiCoeffs->data[detInd2]->a->data[sftInd2] );
   }
 
-  (*G_alpha) = ret;
+  (*Gamma_ave) = ret1;
+  (*Gamma_circ) = ret2;
   return XLAL_SUCCESS;
 }
 
@@ -399,8 +402,143 @@ int XLALCalculatePulsarCrossCorrStatistic
   *ccStat = 4 * multiWeights->Sinv_Tsft * nume / sqrt(*evSquared);
   return XLAL_SUCCESS;
 }
-/*calculate metric diagnol components, also include the estimation of sensitivity E[rho]/(h_0)^2*/
-int XLALFindLMXBCrossCorrDiagMetric
+
+/** calculate signal phase derivatives wrt Doppler coords, for each SFT */
+/* allocates memory as well */
+int XLALCalculateCrossCorrPhaseDerivatives
+  (
+   REAL8VectorSequence        **phaseDerivs, /**< Output: dPhi_K/dlambda_i; i is the "sequence" index, K is the "vector" index */
+   const PulsarDopplerParams  *dopplerPoint, /**< Input: pulsar/binary orbit paramaters */
+   const EphemerisData                *edat, /**< Input: Earth/Sun ephemeris */
+   SFTIndexList                  *indexList, /**< Input: list of SFT indices */
+   MultiSSBtimes                *multiTimes, /**< Input: barycentered times of SFTs */
+   const DopplerCoordinateSystem  *coordSys  /**< Input: coordinates with which to differentiate */
+   )
+{
+  XLAL_CHECK ( dopplerPoint != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( edat != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( indexList != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( multiTimes != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( coordSys != NULL, XLAL_EINVAL );
+
+  const UINT4 numCoords = coordSys->dim;
+  const UINT8 numSFTs = indexList->length;
+
+  REAL8VectorSequence *ret = NULL;
+
+  XLAL_CHECK ( ( ret = XLALCreateREAL8VectorSequence ( numCoords, numSFTs ) ) != NULL, XLAL_EFUNC, "XLALCreateREAL8VectorSequence ( %"LAL_UINT4_FORMAT", %"LAL_UINT8_FORMAT" ) failed.", numCoords,numSFTs );
+
+  for ( UINT4 coordNum=0; coordNum < numCoords; coordNum++ ) {
+    for ( UINT8 sftNum=0; sftNum < numSFTs; sftNum++ ) {
+      UINT8 detInd = indexList->data[sftNum].detInd;
+      UINT8 sftInd = indexList->data[sftNum].sftInd;
+      SSBtimes *times;
+      times = multiTimes->data[detInd];
+      REAL8 refTime8 = XLALGPSGetREAL8 ( &(times->refTime) );
+      UINT8 numSFTsDet = times->DeltaT->length;
+      XLAL_CHECK ( ( sftInd < numSFTsDet ), XLAL_EINVAL, "SFT asked for SFT index off end of list:\n sftNum=%"LAL_UINT8_FORMAT", detInd=%"LAL_UINT8_FORMAT", sftInd=%"LAL_UINT8_FORMAT", numSFTsDet=%"LAL_UINT8_FORMAT"\n", sftNum, detInd, sftInd, numSFTsDet );
+      REAL8 tSSB = refTime8 + times->DeltaT->data[sftInd];
+      ret->data[coordNum*numSFTs+sftNum] = XLALComputePhaseDerivative ( tSSB, dopplerPoint, (coordSys->coordIDs[coordNum]), edat, NULL, 0 );
+      XLAL_CHECK ( xlalErrno == 0, XLAL_EFUNC, "XLALComputePhaseDerivative() failed with xlalErrno = %d\n", xlalErrno );
+    }
+  }
+
+  (*phaseDerivs) = ret;
+
+  return XLAL_SUCCESS;
+
+}
+
+/** calculate phase metric for CW cross-correlation search, as well as vector used for parameter offsets */
+/** This calculates the metric defined in (4.7) of Whelan et al 2015 and the parameter offset epsilon_i */
+/** (not including the cosi-dependent prefactor) in defined in (4.8) */
+/* allocates memory as well */
+int XLALCalculateCrossCorrPhaseMetric
+  (
+   gsl_matrix                        **g_ij, /**< Output: parameter space metric */
+   gsl_vector                       **eps_i, /**< Output: parameter offset vector from (4.8) of WSZP15 */
+   REAL8                        *sumGammaSq, /**< Output: sum of (Gamma_ave)^2 for normalization and sensitivity */
+   const REAL8VectorSequence   *phaseDerivs, /**< Input: dPhi_K/dlambda_i; i is the "sequence" index, K is the "vector" */
+   const SFTPairIndexList    *pairIndexList, /**< Input: list of SFT pairs */
+   const REAL8Vector             *Gamma_ave, /**< Input: vector of aa+bb values */
+   const REAL8Vector            *Gamma_circ, /**< Input: vector of ab-ba values */
+   const DopplerCoordinateSystem  *coordSys  /**< Input: coordinate directions for metric */
+   )
+{
+  XLAL_CHECK ( sumGammaSq != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( phaseDerivs != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( pairIndexList != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( Gamma_ave != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( Gamma_circ != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( coordSys != NULL, XLAL_EINVAL );
+
+  const UINT4 numCoords = coordSys->dim;
+  XLAL_CHECK ( ( phaseDerivs->length == numCoords ), XLAL_EINVAL, "Length mismatch: phaseDerivs->length=%"LAL_UINT4_FORMAT", numCoords=%"LAL_UINT4_FORMAT"\n", phaseDerivs->length, numCoords );
+  const UINT8 numSFTs = phaseDerivs->vectorLength;
+  const UINT8 numPairs = pairIndexList->length;
+  XLAL_CHECK ( ( Gamma_ave->length == numPairs ), XLAL_EINVAL, "Length mismatch: Gamma_ave->length=%"LAL_UINT4_FORMAT", numPairs=%"LAL_UINT8_FORMAT"\n", Gamma_ave->length, numPairs );
+  XLAL_CHECK ( ( Gamma_circ->length == numPairs ), XLAL_EINVAL, "Length mismatch: Gamma_circ->length=%"LAL_UINT4_FORMAT", numPairs=%"LAL_UINT8_FORMAT"\n", Gamma_circ->length, numPairs );
+
+  /* ---------- prepare output metric ---------- */
+  gsl_matrix *ret_g;
+  if ( (ret_g = gsl_matrix_calloc ( numCoords, numCoords )) == NULL ) {
+    XLALPrintError ("%s: gsl_matrix_calloc(%d, %d) failed.\n\n", __func__, numCoords, numCoords );
+    XLAL_ERROR ( XLAL_ENOMEM );
+
+  }
+  gsl_vector *ret_e;
+  if ( (ret_e = gsl_vector_calloc ( numCoords )) == NULL ) {
+    XLALPrintError ("%s: gsl_vector_calloc(%d) failed.\n\n", __func__, numCoords );
+    XLAL_ERROR ( XLAL_ENOMEM );
+  }
+
+  REAL8Vector *dDeltaPhi_i = NULL;
+  REAL8 denom = 0;
+  XLAL_CHECK ( ( dDeltaPhi_i = XLALCreateREAL8Vector ( numCoords ) ) != NULL, XLAL_EFUNC, "XLALCreateREAL8Vector ( %"LAL_UINT4_FORMAT" ) failed.", numCoords );
+  for ( UINT8 pairNum=0; pairNum < numPairs; pairNum++ ) {
+    UINT8 sftNum1 = pairIndexList->data[pairNum].sftNum[0];
+    UINT8 sftNum2 = pairIndexList->data[pairNum].sftNum[1];
+    REAL8 aveWeight = SQUARE(Gamma_ave->data[pairNum]);
+    denom += aveWeight;
+    REAL8 circWeight = Gamma_ave->data[pairNum] * Gamma_circ->data[pairNum];
+    for ( UINT4 i=0; i < numCoords; i++ ) {
+      dDeltaPhi_i->data[i] = phaseDerivs->data[i*numSFTs+sftNum1] - phaseDerivs->data[i*numSFTs+sftNum2];
+      REAL8 epsi = gsl_vector_get( ret_e, i );
+      epsi += circWeight * dDeltaPhi_i->data[i];
+      gsl_vector_set( ret_e, i, epsi );
+      for ( UINT4 j=0; j<=i; j++ ) { /* Doing the loop this way ensures dDeltaPhi_i[j] has been set */
+	REAL8 gij = gsl_matrix_get( ret_g, i, j );
+	gij += aveWeight * dDeltaPhi_i->data[i] * dDeltaPhi_i->data[j];
+	gsl_matrix_set ( ret_g, i, j, gij );
+      }
+    }
+  }
+
+  XLALDestroyREAL8Vector ( dDeltaPhi_i );
+
+  for ( UINT4 i=0; i < numCoords; i++ ) {
+    REAL8 epsi = gsl_vector_get( ret_e, i );
+    epsi /= denom;
+    gsl_vector_set( ret_e, i, epsi );
+    for ( UINT4 j=0; j<=i; j++ ) { /* Doing the loop the same way as above */
+      REAL8 gij = gsl_matrix_get( ret_g, i, j );
+      gij /= (2.*denom);
+      gsl_matrix_set ( ret_g, i, j, gij );
+      if ( i != j ) gsl_matrix_set ( ret_g, j, i, gij );
+    }
+  }
+
+  (*g_ij) = ret_g;
+  (*eps_i) = ret_e;
+  (*sumGammaSq) = denom;
+
+  return XLAL_SUCCESS;
+
+}
+
+
+/*calculate metric diagonal components, also include the estimation of sensitivity E[rho]/(h_0)^2*/
+int XLALCalculateLMXBCrossCorrDiagMetric
   (
    REAL8                      *hSens, /* Output: sensitivity*/
    REAL8                       *g_ff, /* Output: Diagonal frequency metric element */
