@@ -48,11 +48,13 @@
 #endif
 
 #include <lal/LALStdio.h>
+#include <lal/LALString.h>
 #include <lal/FileIO.h>
 #include <lal/SFTfileIO.h>
 #include <lal/StringVector.h>
 #include <lal/Sequence.h>
 #include <lal/ConfigFile.h>
+#include <lal/UserInputParse.h>
 #include <lal/LogPrintf.h>
 #include <lal/SFTutils.h>
 
@@ -907,8 +909,7 @@ XLALLoadSFTs (const SFTCatalog *catalog,   /**< The 'catalogue' of SFTs to load
 	/* data is ok, add to SFT */
 	segments[isft].last               = lastBinRead;
 	segments[isft].lastfrom           = locator;
-	if(locatalog.data[catPos].header.name && *(locatalog.data[catPos].header.name))
-	  strcpy(sftVector->data[isft].name, locatalog.data[catPos].header.name);
+        memcpy( sftVector->data[isft].name, locatalog.data[catPos].header.name, sizeof(sftVector->data[isft].name));
 	sftVector->data[isft].sampleUnits = locatalog.data[catPos].header.sampleUnits;
 	memcpy(sftVector->data[isft].data->data + (firstBinRead - firstbin),
 	       thisSFT->data->data,
@@ -1076,27 +1077,38 @@ XLALReadTimestampsFile ( const CHAR *fname )
   LIGOTimeGPSVector *timestamps = NULL;
   XLAL_CHECK_NULL ( ( timestamps = XLALCreateTimestampVector ( numTS )) != NULL, XLAL_EFUNC );
 
+  char buf[256];
   for ( UINT4 iTS = 0; iTS < numTS; iTS ++ )
     {
+      LIGOTimeGPS gps;
       INT4 secs, ns;
       char junk[11] = "";
-      if ( sscanf ( flines->lines->tokens[iTS], "%d %d%10s\n", &secs, &ns, junk ) != 2 ) {
-        if ( junk[0] != 0 ) { XLALPrintError ("Found junk '%s' after timestamp in line %d/%d\n", junk, iTS+1, numTS ); }
-        XLALPrintError ( "Failed to parse data-line %d: '%s' in timestamps-file '%s' (needs to be in format 'sec ns')\n",
-                         iTS + 1, flines->lines->tokens[iTS], fname );
-        XLALDestroyTimestampVector ( timestamps );
-        XLALDestroyParsedDataFile ( flines );
-        XLAL_ERROR_NULL ( XLAL_ESYS );
-      }
 
-      XLAL_CHECK_NULL ( ( secs >= 0 ) && ( ns >= 0 ), XLAL_EDOM,
-                        "Timestamps-file '%s' contains negative time-entry in line %d : s = %d, ns = %d\n", fname, iTS, secs, ns );
+      // first check if obsolete <sec ns> format is found on this line
+      if ( sscanf ( flines->lines->tokens[iTS], "%" LAL_INT4_FORMAT " %" LAL_INT4_FORMAT "%10s\n", &secs, &ns, junk ) > 1 )
+        {
+          gps.gpsSeconds = secs;
+          gps.gpsNanoSeconds = ns;
 
-      XLAL_CHECK_NULL ( ns <= 999999999, XLAL_EDOM,
-                        "Timestamps-file '%s' contains nano-seconds entry >= 1 billion ns in line %d: s = %d, ns = %d\n", fname, iTS, secs, ns );
+          XLALPrintWarning ( "Line %d: found obsolete 'sec ns' timestamps format '%s', use 'xx.yy[GPS|MJD]' instead: %s\n", iTS, flines->lines->tokens[iTS], XLALGPSToStr(buf,&gps) );
+          if ( junk[0] != 0 )
+            {
+              XLALDestroyTimestampVector ( timestamps );
+              XLALDestroyParsedDataFile ( flines );
+              XLAL_ERROR_NULL ( XLAL_EINVAL, "Unconverted trailing junk '%s' found: invalid\n", junk );
+            }
+        } // end: if old-style format 'sec ns' is found
+      else
+        {
+          if ( XLALParseStringValueAsEPOCH ( &gps, flines->lines->tokens[iTS] ) != XLAL_SUCCESS )
+            {
+              XLALDestroyTimestampVector ( timestamps );
+              XLALDestroyParsedDataFile ( flines );
+              XLAL_ERROR_NULL ( XLAL_EINVAL, "Failed to parse line %d into epoch: '%s'\n", iTS, flines->lines->tokens[iTS] );
+            }
+        }
 
-      timestamps->data[iTS].gpsSeconds     = secs;
-      timestamps->data[iTS].gpsNanoSeconds = ns;
+      timestamps->data[iTS] = gps;
 
     } /* for iTS < numTS */
 
@@ -1472,7 +1484,7 @@ XLALshowSFTLocator ( const struct tagSFTLocator *locator )
     return NULL;
 
   snprintf ( ret, sizeof(ret), "%s : %ld", locator->fname, locator->offset );
-  ret[ sizeof(ret) - 1 ] = 0;
+  XLAL_LAST_ELEM(ret) = 0;
 
   return ret;
 
@@ -1790,17 +1802,17 @@ XLALOfficialSFTFilename ( char site,		//!< site-character 'G', 'H', 'L', ...
   char D[512];
   char IFO[2] = { site, channel };
   size_t written = snprintf ( D, sizeof(D), "%d_%c%c_%dSFT%s%s", numSFTs, IFO[0], IFO[1], Tsft, Misc ? "_" : "", Misc ? Misc : "" );
-  XLAL_CHECK_NULL ( written < sizeof(D), XLAL_EINVAL, "Description field length of %d exceeds buffer length of %d characters\n", written, sizeof(D)-1 );
+  XLAL_CHECK_NULL ( written < sizeof(D), XLAL_EINVAL, "Description field length of %zu exceeds buffer length of %zu characters\n", written, sizeof(D)-1 );
 
   // ----- G
   char G[11];
   written = snprintf ( G, sizeof(G), "%09d", GPS_start );
-  XLAL_CHECK_NULL ( written < sizeof(G), XLAL_EINVAL, "GPS seconds %d exceed buffer length of %d characters\n", GPS_start, sizeof(G)-1 );
+  XLAL_CHECK_NULL ( written < sizeof(G), XLAL_EINVAL, "GPS seconds %d exceed buffer length of %zu characters\n", GPS_start, sizeof(G)-1 );
 
   // ----- T
   char T[10];
   written = snprintf ( T, sizeof(T), "%d", Tspan );
-  XLAL_CHECK_NULL ( written < sizeof(T), XLAL_EINVAL, "Tspan=%d s exceed buffer length of %d characters\n", Tspan, sizeof(T)-1 );
+  XLAL_CHECK_NULL ( written < sizeof(T), XLAL_EINVAL, "Tspan=%d s exceed buffer length of %zu characters\n", Tspan, sizeof(T)-1 );
 
   // S-D-G-T.sft
   size_t len = strlen(S) + 1 + strlen(D) + 1 + strlen(G) + 1 + strlen(T) + 4 + 1;
@@ -1808,7 +1820,7 @@ XLALOfficialSFTFilename ( char site,		//!< site-character 'G', 'H', 'L', ...
   XLAL_CHECK_NULL ( (filename = XLALCalloc ( 1, len )) != NULL, XLAL_ENOMEM );
 
   written = snprintf ( filename, len, "%s-%s-%s-%s.sft", S, D, G, T );
-  XLAL_CHECK_NULL ( written < len, XLAL_EFAILED, "Miscounted string-length, expected %d characters but got %d\n", len - 1, written );
+  XLAL_CHECK_NULL ( written < len, XLAL_EFAILED, "Miscounted string-length, expected %zu characters but got %zu\n", len - 1, written );
 
   return filename;
 
@@ -2172,7 +2184,7 @@ read_v2_header_from_fp ( FILE *fp, SFTtype *header, UINT4 *nsamples, UINT8 *head
   /* double-check version-number */
   if ( rawheader.version != 2 )
     {
-      XLALPrintError ("\nWrong SFT-version %d in read_v2_header_from_fp()\n\n", rawheader.version );
+      XLALPrintError ("\nWrong SFT-version %g in read_v2_header_from_fp()\n\n", rawheader.version );
       goto failed;
     }
 
@@ -2214,7 +2226,7 @@ read_v2_header_from_fp ( FILE *fp, SFTtype *header, UINT4 *nsamples, UINT8 *head
 	}
       if ( (size_t)rawheader.comment_length != fread ( comm, 1, rawheader.comment_length, fp ) )
 	{
-	  XLALPrintError ("\nCould not read %d-bytes comment\n\n");
+	  XLALPrintError ("\nCould not read %d-bytes comment\n\n", rawheader.comment_length);
 	  goto failed;
 	}
 
@@ -2482,17 +2494,10 @@ XLALFindFiles (const CHAR *globstring)
     LALParsedDataFile *list = NULL;
     CHAR* listfname = NULL;
 
-    /* create list file name
-       prefix with "./" if not an absolute file name (see LALOpenDataFile()) */
-    if ((listfname = LALCalloc(1, strlen(globstring) + 3)) == NULL) {
+    /* extract list file name */
+    if ((listfname = XLALStringDuplicate(globstring + strlen(LIST_PREFIX))) == NULL) {
       XLAL_ERROR_NULL ( XLAL_ENOMEM ) ;
     }
-    ptr1 = globstring + strlen(LIST_PREFIX);
-    if (*ptr1 == '/')
-      *listfname = '\0';
-    else
-      strcpy(listfname, "./");
-    strcat(listfname, ptr1);
 #undef LIST_PREFIX
 
     /* read list of file names from file */
