@@ -226,212 +226,6 @@ LALCopySFT (LALStatus *status,	/**< pointer to LALStatus structure */
 
 } /* LALCopySFT() */
 
-/**
- * Subtract two SFT-vectors and put the results in a new one (which it allocates).
- *
- */
-void
-LALSubtractSFTVectors (LALStatus *status,	/**< pointer to LALStatus structure */
-		     SFTVector **outVect,	/**< [out] difference of SFT-vectors */
-		     const SFTVector *inVect1,	/**< input-vector 1 */
-		     const SFTVector *inVect2 ) /**< input-vector 2 */
-{
-  UINT4 numSFTs1, numSFTs2;
-  UINT4 i, j;
-  SFTVector *ret = NULL;
-  CHAR name1Trunc[LALNameLength];
-  CHAR name2Trunc[LALNameLength];
-  CHAR prefix[LALNameLength];
-  UINT4 halfNameLength;
-
-  INITSTATUS(status);
-  ATTATCHSTATUSPTR (status);
-
-  ASSERT (outVect,  status, SFTUTILS_ENULL,  SFTUTILS_MSGENULL);
-  ASSERT ( *outVect == NULL,  status, SFTUTILS_ENONULL,  SFTUTILS_MSGENONULL);
-  ASSERT (inVect1 && inVect1->data, status, SFTUTILS_ENULL,  SFTUTILS_MSGENULL);
-  ASSERT (inVect2 && inVect2->data, status, SFTUTILS_ENULL,  SFTUTILS_MSGENULL);
-  ASSERT ( inVect1->data[0].data && inVect2->data[0].data, status, SFTUTILS_ENULL,  SFTUTILS_MSGENULL);
-
-  numSFTs1 = inVect1 -> length;
-  numSFTs2 = inVect2 -> length;
-
-  if ( numSFTs1 != numSFTs2 )
-    {
-      XLALPrintError ("\nERROR: the SFT-vectors must have the same number of SFTs!\n\n");
-      ABORT ( status, SFTUTILS_EINPUT,  SFTUTILS_MSGEINPUT);
-    }
-
-  TRY ( LALCreateSFTVector ( status->statusPtr, &ret, numSFTs1, inVect1->data[0].data->length ), status );
-
-  halfNameLength = (LALNameLength - strlen("Xn:{}-{}"))/2;
-
-  /* copy the SFTs and subtract their data one-by-one */
-  for (i=0; i < numSFTs1; i ++)
-    {
-      UINT4 numBins1, numBins2;
-      LIGOTimeGPS epoch1, epoch2;
-      REAL8 Freq1, Freq2, deltaF1, deltaF2;
-      numBins1 = inVect1->data[i].data->length;
-      numBins2 = inVect2->data[i].data->length;
-      epoch1   = inVect1->data[i].epoch;
-      epoch2   = inVect2->data[i].epoch;
-      Freq1    = inVect1->data[i].f0;
-      Freq2    = inVect2->data[i].f0;
-      deltaF1  = inVect1->data[i].deltaF;
-      deltaF2  = inVect2->data[i].deltaF;
-
-      if ( numBins1 != numBins2 ) {
-	XLALPrintError ("\nERROR: the SFTs must have the same number of frequency-bins!\n\n");
-	goto failed;
-      }
-      if ( (epoch1.gpsSeconds != epoch2.gpsSeconds) || ( epoch1.gpsNanoSeconds != epoch2.gpsNanoSeconds ) ) {
-	XLALPrintError ("\nERROR: the SFTs must have the same epochs!\n\n");
-	goto failed;
-      }
-      if ( Freq1 != Freq2 ) {
-	XLALPrintError ("\nERROR: the SFTs must have the same start frequency!\n\n");
-	goto failed;
-      }
-      if ( deltaF1 != deltaF2 ) {
-	XLALPrintError ("\nERROR: the SFTs must have the same frequency-steps!\n\n");
-	goto failed;
-      }
-      /* copy header info */
-      ret->data[i].epoch  = epoch1;
-      ret->data[i].f0     = Freq1;
-      ret->data[i].deltaF = deltaF1;
-
-      for (j=0; j < numBins1; j++)
-	{
-	  ret->data[i].data->data[j] = crectf( crealf(inVect1->data[i].data->data[j]) - crealf(inVect2->data[i].data->data[j]), cimagf(inVect1->data[i].data->data[j]) - cimagf(inVect2->data[i].data->data[j]) );
-	}  /* for j < numBins1 */
-
-      snprintf ( name1Trunc, halfNameLength, "%s", inVect1->data[i].name );
-      snprintf ( name2Trunc, halfNameLength, "%s", inVect2->data[i].name );
-      snprintf ( prefix, (strlen("Xn:") + 1), "%s", inVect1->data[i].name );
-      snprintf ( ret->data[i].name, LALNameLength, "%s{%s}-{%s}", prefix, name1Trunc, name2Trunc );
-    } /* for i < numSFTs1 */
-
-  /* success: */
-  (*outVect) = ret;
-  DETATCHSTATUSPTR (status);
-  RETURN (status);
-
- failed:
-  LALDestroySFTVector (  status->statusPtr, &ret );
-  ABORT ( status, SFTUTILS_EINPUT,  SFTUTILS_MSGEINPUT);
-
-} /* LALSubtractSFTVectors() */
-
-
-
-/**
- * Linearly combine two or more SFT-vectors and put the results in a new one (which it allocates).
- */
-void
-LALLinearlyCombineSFTVectors
-(LALStatus *status,		/**< pointer to LALStatus structure */
- SFTVector **outVect,	          /**< [out] linear combo of SFT-vectors */
- SFTVector **inVects,	  /**< array of SFT-vectors */
- const COMPLEX16Vector *weights,  /**< vector of SFT-weights */
- const CHAR *outName)             /**< name for output vector */
-{
-  UINT4 numSFTs, numSFTVects;
-  UINT4 i, j, k;
-  SFTVector *ret = NULL;
-
-  INITSTATUS(status);
-  ATTATCHSTATUSPTR (status);
-
-  ASSERT (outVect,  status, SFTUTILS_ENULL,  SFTUTILS_MSGENULL);
-  ASSERT ( *outVect == NULL,  status, SFTUTILS_ENONULL,  SFTUTILS_MSGENONULL);
-  ASSERT (inVects && inVects[0] && inVects[0]->data
-	  && inVects[0]->data[0].data,
-	  status, SFTUTILS_ENULL, SFTUTILS_MSGENULL);
-  ASSERT (weights && weights->data,
-	  status, SFTUTILS_ENULL,  SFTUTILS_MSGENULL);
-  numSFTVects = weights->length;
-
-  if ( numSFTVects < 1 )
-    {
-      XLALPrintError ("\nERROR: must be combining at least one SFT Vector!\n\n");
-      ABORT ( status, SFTUTILS_EINPUT,  SFTUTILS_MSGEINPUT);
-    }
-
-  numSFTs = inVects[0] -> length;
-
-  TRY ( LALCreateSFTVector ( status->statusPtr, &ret, numSFTs, inVects[0]->data[0].data->length ), status );
-
-  /* copy the SFTs from the first vector */
-  for (i=0; i < numSFTs; i ++)
-    {
-      UINT4 numBins1, numBins2;
-      LIGOTimeGPS epoch1, epoch2;
-      REAL8 Freq1, Freq2, deltaF1, deltaF2;
-      numBins1 = inVects[0]->data[i].data->length;
-      epoch1   = inVects[0]->data[i].epoch;
-      Freq1    = inVects[0]->data[i].f0;
-      deltaF1  = inVects[0]->data[i].deltaF;
-
-      /* copy header info */
-      ret->data[i].epoch  = epoch1;
-      ret->data[i].f0     = Freq1;
-      ret->data[i].deltaF = deltaF1;
-
-      for (k=0; k < numBins1; k++)
-	{
-	  ret->data[i].data->data[k] = crectf( creal(weights->data[0]) * crealf(inVects[0]->data[i].data->data[k]) - cimag(weights->data[0]) * cimagf(inVects[0]->data[i].data->data[k]), creal(weights->data[0]) * cimagf(inVects[0]->data[i].data->data[k]) + cimag(weights->data[0]) * crealf(inVects[0]->data[i].data->data[k]) );
-	}  /* for k < numBins1 */
-
-      /* add in the other SFTs one-by-one */
-      for (j=1; j < numSFTVects; j++)
-	{
-	  numBins2 = inVects[j]->data[i].data->length;
-	  epoch2   = inVects[j]->data[i].epoch;
-	  Freq2    = inVects[j]->data[i].f0;
-	  deltaF2  = inVects[j]->data[i].deltaF;
-
-	  if ( numBins1 != numBins2 ) {
-	    XLALPrintError ("\nERROR: the SFTs must have the same number of frequency-bins!\n\n");
-	    goto failed;
-	  }
-	  if ( (epoch1.gpsSeconds != epoch2.gpsSeconds) || ( epoch1.gpsNanoSeconds != epoch2.gpsNanoSeconds ) ) {
-	    XLALPrintError ("\nERROR: the SFTs must have the same epochs!\n\n");
-	    goto failed;
-	  }
-	  if ( Freq1 != Freq2 ) {
-	    XLALPrintError ("\nERROR: the SFTs must have the same start frequency!\n\n");
-	    goto failed;
-	  }
-	  if ( deltaF1 != deltaF2 ) {
-	    XLALPrintError ("\nERROR: the SFTs must have the same frequency-steps!\n\n");
-	    goto failed;
-	  }
-
-
-	  for (k=0; k < numBins1; k++)
-	    {
-	      ret->data[i].data->data[k] += crectf( creal(weights->data[j]) * crealf(inVects[j]->data[i].data->data[k]) - cimag(weights->data[j]) * cimagf(inVects[j]->data[i].data->data[k]), creal(weights->data[j]) * cimagf(inVects[j]->data[i].data->data[k]) + cimag(weights->data[j]) * crealf(inVects[j]->data[i].data->data[k]) );
-	    }  /* for k < numBins1 */
-
-	} /* for j < numSFTVects */
-      memcpy ( ret->data[i].name, outName, LALNameLength*sizeof(CHAR) );
-    } /* for i < numSFTs */
-
-  /* success: */
-  (*outVect) = ret;
-  DETATCHSTATUSPTR (status);
-  RETURN (status);
-
- failed:
-  LALDestroySFTVector (  status->statusPtr, &ret );
-  ABORT ( status, SFTUTILS_EINPUT,  SFTUTILS_MSGEINPUT);
-
-} /* LALLinearlyCombineSFTVectors() */
-
-
-
 /** Append the given SFTtype to the SFT-vector (no SFT-specific checks are done!) */
 void
 LALAppendSFT2Vector (LALStatus *status,		/**< pointer to LALStatus structure */
