@@ -33,6 +33,7 @@
 #include <lal/SuperskyMetrics.h>
 #include <lal/LALConstants.h>
 #include <lal/MetricUtils.h>
+#include <lal/ExtrapolatePulsarSpins.h>
 
 #include "GSLHelpers.h"
 
@@ -673,7 +674,7 @@ int XLALConvertSuperskyCoordinates(
   // Check input
   XLAL_CHECK( out < SC_MAX, XLAL_EINVAL );
   XLAL_CHECK( in < SC_MAX, XLAL_EINVAL );
-  XLAL_CHECK( out_points != NULL && *out_points != NULL, XLAL_EFAULT );
+  XLAL_CHECK( out_points != NULL, XLAL_EFAULT );
   XLAL_CHECK( in_points != NULL, XLAL_EINVAL );
   XLAL_CHECK( rssky_transf != NULL || ( out != SC_RSSKY && in != SC_RSSKY ), XLAL_EINVAL );
 
@@ -682,12 +683,16 @@ int XLALConvertSuperskyCoordinates(
   XLAL_CHECK( in_points->size1 > in_ssize, XLAL_EINVAL );
   const size_t fsize = in_points->size1 - in_ssize;
 
-  // Resize output points matrix, if required
+  // Resize or allocate output points matrix, if required
   const size_t out_ssize = ( out == SC_USSKY ) ? 3 : 2;
   const size_t out_rows = fsize + out_ssize;
-  XLAL_CHECK( ( *out_points )->size1 == out_rows, XLAL_EINVAL );
-  if( ( *out_points )->size2 != in_points->size2 ) {
-    gsl_matrix_free( *out_points );
+  if( *out_points != NULL ) {
+    if( ( *out_points )->size1 != out_rows || ( *out_points )->size2 != in_points->size2 ) {
+      gsl_matrix_free( *out_points );
+      *out_points = NULL;
+    }
+  }
+  if( *out_points == NULL ) {
     GAMAT( *out_points, out_rows, in_points->size2 );
   }
 
@@ -831,7 +836,8 @@ int XLALConvertPhysicalToSupersky(
   const SuperskyCoordinates out,
   gsl_vector *out_point,
   const PulsarDopplerParams *in_phys,
-  const gsl_matrix *rssky_transf
+  const gsl_matrix *rssky_transf,
+  const LIGOTimeGPS *ref_time
   )
 {
 
@@ -839,6 +845,7 @@ int XLALConvertPhysicalToSupersky(
   XLAL_CHECK( SC_PHYS < out && out < SC_MAX, XLAL_EINVAL );
   XLAL_CHECK( out_point != NULL, XLAL_EFAULT );
   XLAL_CHECK( in_phys != NULL, XLAL_EFAULT );
+  XLAL_CHECK( ref_time != NULL, XLAL_EFAULT );
 
   // Deduce number of sky coordinates, and frequency/spindown coordinates
   const size_t ssize = ( out == SC_USSKY ) ? 3 : 2;
@@ -846,11 +853,18 @@ int XLALConvertPhysicalToSupersky(
   const size_t fsize = out_point->size - ssize;
   XLAL_CHECK( fsize <= PULSAR_MAX_SPINS, XLAL_EFAILED );
 
+  // Transform input physical point to reference time of coordinate transform data
+  PulsarDopplerParams in_phys_ref = *in_phys;
+  {
+    const REAL8 dtau = XLALGPSDiff ( ref_time, &in_phys_ref.refTime );
+    XLAL_CHECK ( XLALExtrapolatePulsarSpins ( in_phys_ref.fkdot, in_phys_ref.fkdot, dtau ) == XLAL_SUCCESS, XLAL_EFUNC );
+  }
+
   // Copy input physical point to array
   double in_point[2 + fsize];
-  in_point[0] = in_phys->Alpha;
-  in_point[1] = in_phys->Delta;
-  memcpy( &in_point[2], in_phys->fkdot, fsize * sizeof( in_point[0] ) );
+  in_point[0] = in_phys_ref.Alpha;
+  in_point[1] = in_phys_ref.Delta;
+  memcpy( &in_point[2], in_phys_ref.fkdot, fsize * sizeof( in_point[0] ) );
 
   // Convert input physical point to output supersky coordinate point
   gsl_matrix_view out_point_view = gsl_matrix_view_vector( out_point, out_point->size, 1 );
@@ -867,7 +881,8 @@ int XLALConvertSuperskyToPhysical(
   PulsarDopplerParams *out_phys,
   const SuperskyCoordinates in,
   const gsl_vector *in_point,
-  const gsl_matrix *rssky_transf
+  const gsl_matrix *rssky_transf,
+  const LIGOTimeGPS *ref_time
   )
 {
 
@@ -875,6 +890,7 @@ int XLALConvertSuperskyToPhysical(
   XLAL_CHECK( out_phys != NULL, XLAL_EFAULT );
   XLAL_CHECK( SC_PHYS < in && in < SC_MAX, XLAL_EINVAL );
   XLAL_CHECK( in_point != NULL, XLAL_EFAULT );
+  XLAL_CHECK( ref_time != NULL, XLAL_EFAULT );
 
   // Deduce number of sky coordinates, and frequency/spindown coordinates
   const size_t ssize = ( in == SC_USSKY ) ? 3 : 2;
@@ -895,6 +911,9 @@ int XLALConvertSuperskyToPhysical(
   out_phys->Delta = out_point[1];
   memcpy( out_phys->fkdot, &out_point[2], fsize * sizeof( out_point[0] ) );
 
+  // Set output physical point reference time to that of of coordinate transform data
+  out_phys->refTime = *ref_time;
+
   return XLAL_SUCCESS;
 
 }
@@ -938,22 +957,66 @@ static double SuperskyBCoordBound(
 
 int XLALSetSuperskyLatticeTilingAllSkyBounds(
   LatticeTiling *tiling,
-  const size_t patch_count_A,
-  const size_t patch_count_B,
-  const size_t patch_index_A,
-  const size_t patch_index_B
+  const double patch_B_extent,
+  const UINT8 patch_count,
+  const UINT8 patch_index
   )
 {
 
   // Check input
   XLAL_CHECK( tiling != NULL, XLAL_EFAULT );
-  XLAL_CHECK( patch_count_A > 0, XLAL_EINVAL );
-  XLAL_CHECK( patch_count_B > 0, XLAL_EINVAL );
-  XLAL_CHECK( patch_index_A < patch_count_A, XLAL_EINVAL );
-  XLAL_CHECK( patch_index_B < patch_count_B, XLAL_EINVAL );
+  XLAL_CHECK( patch_B_extent > 0.0, XLAL_EINVAL );
+  XLAL_CHECK( patch_count > 0, XLAL_EINVAL );
+  XLAL_CHECK( patch_index < patch_count, XLAL_EINVAL );
 
-  // Allocate GSL root solver for finding reduced supersky A coordinate bounds
-  gsl_root_fsolver *GALLOC( skyA_bounds_fsolver, gsl_root_fsolver_alloc( gsl_root_fsolver_brent ) );
+  // Calculate patch indexes and counts in reduced supersky coordinate A and B directions.
+  // 'max_patch_B_extent' is used to calculate a minimum number of patches in the B coordinate
+  // direction, 'min_patch_count_B', which with 'patch_count' is used to calculate the number
+  // of patches in the A coordinate direction, 'patch_count_A'. The produce of these two counts
+  // will never exceed 'patch_count'; any excess patches are then added to 'min_patch_count_B'
+  // as required to make up 'patch_count'. For example, given
+  //   'patch_count' = 14, 'patch_count_A' = 4, 'min_patch_count_B' = 3,
+  // the number of patches is partitioned as [4, 4, 3, 3], i.e.
+  //   'patch_index_A' = 0, 'patch_count_B' = 4, 'patch_index_B' = 0 to 3
+  //   'patch_index_A' = 1, 'patch_count_B' = 4, 'patch_index_B' = 0 to 3
+  //   'patch_index_A' = 2, 'patch_count_B' = 3, 'patch_index_B' = 0 to 2
+  //   'patch_index_A' = 3, 'patch_count_B' = 3, 'patch_index_B' = 0 to 2
+
+  // Approximate minimum number of patches in B coordinate
+  const double approx_min_patch_count_B = 2.0 / patch_B_extent;
+
+  // Number of patches in A coordinate
+  const UINT8 patch_count_A = GSL_MAX( 1, lround( floor( patch_count / approx_min_patch_count_B ) ) );
+
+  // Actual minimum number of patches in B coordinate; note integer division equivalent to floor()
+  const UINT8 min_patch_count_B = patch_count / patch_count_A;
+
+  // Excess number of patches which must be added on to get 'patch_count'
+  INT8 patch_excess = patch_count - patch_count_A * min_patch_count_B;
+  XLAL_CHECK( patch_excess >= 0, XLAL_EFAILED );
+
+  // Initialise number of patches in B coordinate; if there are excess patches, add an extra patch
+  UINT8 patch_count_B = min_patch_count_B;
+  if( patch_excess > 0) {
+    ++patch_count_B;
+  }
+
+  // Initialise patch indexes in A and B coordinates
+  UINT8 patch_index_A = 0, patch_index_B = patch_index;
+
+  while( patch_index_B >= patch_count_B ) {
+
+    // Increase patch index in A coordinate, substract patch count in B coordinate from patch index
+    ++patch_index_A;
+    patch_index_B -= patch_count_B;
+
+    // Decrease number of excess patches; if zero, subtract extra patch from patch count in B coordinate
+    --patch_excess;
+    if( patch_excess == 0 ) {
+      --patch_count_B;
+    }
+
+  }
 
   // The reduced supersky A coordinate is bounded from 'skyA_bounds[0]' to 'skyA_bounds[1]'. The
   // value of 'skyA_bounds[i]' is chosen such that the fractional area of the sky (shaded # in the
@@ -977,10 +1040,13 @@ int XLALSetSuperskyLatticeTilingAllSkyBounds(
   //   'skyA_bounds[i]' = -1.0 + 2.0*'skyA_hemi' + 'x'
   // where 'skyA_hemi' is 0.0 for the left hemisphere and 1.0 for the right hemisphere.
 
+  // Allocate GSL root solver for finding reduced supersky A coordinate bounds
+  gsl_root_fsolver *GALLOC( skyA_bounds_fsolver, gsl_root_fsolver_alloc( gsl_root_fsolver_brent ) );
+
   // Compute the lower and upper bounds on reduced supersky A coordinate
   double skyA_bounds[2] = {0, 0};
   for( size_t i = 0; i < 2; ++i ) {
-    const size_t iA = patch_index_A + i;
+    const UINT8 iA = patch_index_A + i;
 
     // Treat special value of 'iA' where root-finding is not required separately
     if( iA == 0 ) {
@@ -1073,7 +1139,7 @@ int XLALSetSuperskyLatticeTilingSkyPointBounds(
   PulsarDopplerParams XLAL_INIT_DECL( doppler );
   doppler.Alpha = alpha;
   doppler.Delta = delta;
-  XLAL_CHECK( XLALConvertPhysicalToSupersky( SC_RSSKY, rssky_point, &doppler, rssky_transf ) == XLAL_SUCCESS, XLAL_EFUNC );
+  XLAL_CHECK( XLALConvertPhysicalToSupersky( SC_RSSKY, rssky_point, &doppler, rssky_transf, &doppler.refTime ) == XLAL_SUCCESS, XLAL_EFUNC );
 
   // Set the parameter-space bounds on 2-dimensional reduced supersky A and B coordinates
   for( size_t i = 0; i < 2; ++i ) {
@@ -1174,3 +1240,86 @@ int XLALSetSuperskyLatticeTilingCoordinateSpinBound(
   return XLAL_SUCCESS;
 
 }
+
+int XLALSuperskyLatticePulsarSpinRange(
+  PulsarSpinRange *spin_range,
+  LatticeTiling *tiling,
+  const gsl_matrix *rssky_transf,
+  const LIGOTimeGPS *ref_time
+  )
+{
+
+  // Check input
+  XLAL_CHECK( spin_range != NULL, XLAL_EFAULT );
+  XLAL_CHECK( tiling != NULL, XLAL_EFAULT );
+  XLAL_CHECK( rssky_transf != NULL, XLAL_EFAULT );
+  XLAL_CHECK( ref_time != NULL, XLAL_EFAULT );
+
+  // Get rectange containing range reduced supersky coordinates
+  double skyA_rect[4], skyB_rect[4];
+  {
+    const LatticeTilingStats *stats = XLALLatticeTilingStatistics( tiling, 0 );
+    XLAL_CHECK( stats != NULL, XLAL_EFUNC );
+    skyA_rect[0] = stats->min_value_pass;
+    skyA_rect[1] = stats->max_value_pass;
+    skyA_rect[2] = stats->max_value_pass;
+    skyA_rect[3] = stats->min_value_pass;
+  }
+  {
+    const LatticeTilingStats *stats = XLALLatticeTilingStatistics( tiling, 1 );
+    XLAL_CHECK( stats != NULL, XLAL_EFUNC );
+    skyB_rect[0] = stats->min_value_pass;
+    skyB_rect[1] = stats->min_value_pass;
+    skyB_rect[2] = stats->max_value_pass;
+    skyB_rect[3] = stats->max_value_pass;
+  }
+
+  // Get range of physical frequency/spindowns
+  const size_t smax = rssky_transf->size1 - 4;
+  for( size_t i = 0; i < 4; ++i ) {
+
+    // Construct reduced supersky point
+    double in_rssky[3 + smax];
+    in_rssky[0] = skyA_rect[i];
+    in_rssky[1] = skyB_rect[i];
+    for( size_t s = 0; s <= smax; ++s ) {
+      const size_t dim = ( s == 0 ) ? ( 2 + smax ) : ( 1 + s );
+      const LatticeTilingStats *stats = XLALLatticeTilingStatistics( tiling, dim );
+      XLAL_CHECK( stats != NULL, XLAL_EFUNC );
+      in_rssky[dim] = stats->min_value_pass;
+    }
+
+    // Convert reduced supersky point to physical coordinates
+    gsl_vector_view in_rssky_view = gsl_vector_view_array( in_rssky, 3 + smax );
+    PulsarDopplerParams XLAL_INIT_DECL( out_phys );
+    XLAL_CHECK( XLALConvertSuperskyToPhysical( &out_phys, SC_RSSKY, &in_rssky_view.vector, rssky_transf, ref_time ) == XLAL_SUCCESS, XLAL_EFUNC );
+
+    // Store minimum/maximum physical frequency/spindown in 'spin_range'
+    for( size_t s = 0; s <= smax; ++s ) {
+      if( i == 0 || out_phys.fkdot[s] < spin_range->fkdot[s] ) {
+        spin_range->fkdot[s] = out_phys.fkdot[s];
+      }
+      if( i == 0 || out_phys.fkdot[s] > spin_range->fkdotBand[s] ) {
+        spin_range->fkdotBand[s] = out_phys.fkdot[s];
+      }
+    }
+
+  }
+  for( size_t s = 0; s <= smax; ++s ) {
+    spin_range->fkdotBand[s] -= spin_range->fkdot[s];
+  }
+
+  // Adjust 'spin_range' bands to include width of supersky frequency/spindown parameter space
+  for( size_t s = 0; s <= smax; ++s ) {
+    const size_t dim = ( s == 0 ) ? ( 2 + smax ) : ( 1 + s );
+    const LatticeTilingStats *stats = XLALLatticeTilingStatistics( tiling, dim );
+    XLAL_CHECK( stats != NULL, XLAL_EFUNC );
+    spin_range->fkdotBand[s] += stats->max_value_pass - stats->min_value_pass;
+  }
+
+  // Set reference time of 'spin_range' to that of coordinate transform data
+  spin_range->refTime = *ref_time;
+
+  return XLAL_SUCCESS;
+
+}
